@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 Stefan Majewsky <majewsky.stefan@ages-skripte.org>
+ *   Copyright 2008-2010 Stefan Majewsky <majewsky@gmx.net>
  *
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public
@@ -17,12 +17,11 @@
  ***************************************************************************/
 
 #include "mainwindow.h"
-#include "board.h"
-#include "container.h"
+#include "game.h"
 #include "game-state.h"
 #include "infobar.h"
-#include "renderer.h"
 #include "settings.h"
+#include <KGameRenderer>
 #include "view.h"
 
 #include <QCloseEvent>
@@ -46,19 +45,20 @@
 
 MainWindow::MainWindow(QWidget *parent)
 	: KXmlGuiWindow(parent)
-	, m_game(new KDiamond::GameState)
-	, m_board(0)
+	, m_gameState(new KDiamond::GameState)
+	, m_game(0)
 	, m_view(new KDiamond::View)
 	, m_infoBar(0)
-	, m_newAct(new KActionMenu(KIcon("document-new"), i18nc("new game", "&New"), this))
+	, m_newAct(new KActionMenu(KIcon( QLatin1String( "document-new") ), i18nc("new game", "&New" ), this))
 	, m_newTimedAct(new KAction(i18n("Timed game"), this))
 	, m_newUntimedAct(new KAction(i18n("Untimed game"), this))
 {
+	KDiamond::renderer()->setDefaultPrimaryView(m_view);
 	//init GUI - "New Action"
 	m_newAct->setShortcut(KStandardShortcut::openNew());
 	m_newAct->setToolTip(i18n("Start a new game"));
 	m_newAct->setWhatsThis(i18n("Start a new game."));
-	actionCollection()->addAction("game_new", m_newAct);
+	actionCollection()->addAction( QLatin1String( "game_new" ), m_newAct);
 	connect(m_newAct, SIGNAL(triggered()), this, SLOT(startGameDispatcher()));
 	m_newAct->addAction(m_newTimedAct);
 	connect(m_newTimedAct, SIGNAL(triggered()), this, SLOT(startGameDispatcher()));
@@ -66,25 +66,11 @@ MainWindow::MainWindow(QWidget *parent)
 	connect(m_newUntimedAct, SIGNAL(triggered()), this, SLOT(startGameDispatcher()));
 	//init GUI - the other actions
 	KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
-	KStandardGameAction::pause(this, SLOT(pausedAction(bool)), actionCollection());
+	m_pauseAct = KStandardGameAction::pause(this, SLOT(pausedAction(bool)), actionCollection());
 	KStandardGameAction::quit(kapp, SLOT(quit()), actionCollection());
-	KStandardGameAction::hint(0, 0, actionCollection());
+	m_hintAct = KStandardGameAction::hint(0, 0, actionCollection());
 	KStandardAction::preferences(this, SLOT(configureSettings()), actionCollection());
 	KStandardAction::configureNotifications(this, SLOT(configureNotifications()), actionCollection());
-	KToggleAction *showMinutes = actionCollection()->add<KToggleAction>("show_minutes");
-	showMinutes->setText(i18n("Show minutes on timer"));
-	showMinutes->setChecked(Settings::showMinutes()); //the triggered() signal is connected once m_infoBar becomes available
-	//late GUI initialisation
-	setupGUI(QSize(300, 400)); //TODO: find better solution for a minimum size
-	setCaption(i18nc("The application's name", "KDiamond"));
-	setCentralWidget(m_view);
-	connect(m_view, SIGNAL(resized()), this, SLOT(updateTheme()));
-	//init statusbar
-	m_infoBar = new KDiamond::InfoBar(statusBar());
-	connect(showMinutes, SIGNAL(triggered(bool)), m_infoBar, SLOT(setShowMinutes(bool)));
-	connect(m_game, SIGNAL(stateChanged(KDiamond::State)), this, SLOT(stateChange(KDiamond::State)));
-	connect(m_game, SIGNAL(pointsChanged(int)), m_infoBar, SLOT(updatePoints(int)));
-	connect(m_game, SIGNAL(leftTimeChanged(int)), m_infoBar, SLOT(updateRemainingTime(int)));
 	//difficulty
 	KGameDifficulty::init(this, this, SLOT(startGameDispatcher()));
 	KGameDifficulty::addStandardLevel(KGameDifficulty::VeryEasy);
@@ -92,6 +78,15 @@ MainWindow::MainWindow(QWidget *parent)
 	KGameDifficulty::addStandardLevel(KGameDifficulty::Medium);
 	KGameDifficulty::addStandardLevel(KGameDifficulty::Hard);
 	KGameDifficulty::addStandardLevel(KGameDifficulty::VeryHard);
+	//late GUI initialisation
+	setupGUI(QSize(300, 400)); //TODO: find better solution for a minimum size
+	setCaption(i18nc("The application's name", "KDiamond"));
+	setCentralWidget(m_view);
+	//init statusbar
+	m_infoBar = new KDiamond::InfoBar(statusBar());
+	connect(m_gameState, SIGNAL(stateChanged(KDiamond::State)), this, SLOT(stateChange(KDiamond::State)));
+	connect(m_gameState, SIGNAL(pointsChanged(int)), m_infoBar, SLOT(updatePoints(int)));
+	connect(m_gameState, SIGNAL(leftTimeChanged(int)), m_infoBar, SLOT(updateRemainingTime(int)));
 	//selected skill
 	int skill = Settings::skill();
 	if (skill < KGameDifficulty::VeryEasy) //includes default values like 0 or 1
@@ -104,6 +99,7 @@ MainWindow::~MainWindow()
 {
 	Settings::self()->writeConfig();
 	delete m_game;
+	delete m_gameState;
 }
 
 void MainWindow::startGameDispatcher()
@@ -123,29 +119,18 @@ void MainWindow::startGame(KDiamond::Mode mode)
 	KGameDifficulty::standardLevel level = KGameDifficulty::level();
 	Settings::setSkill((int) level);
 	//delete old board
-	if (m_board != 0)
-		delete m_board;
+	delete m_game;
 	//start new game
-	m_game->startNewGame();
-	m_game->setMode(mode);
-	m_board = new Board(m_game, KGameDifficulty::level());
-	updateTheme(false); //initializes the theme
-	connect(m_game, SIGNAL(stateChanged(KDiamond::State)), m_board, SLOT(stateChange(KDiamond::State)));
-	connect(m_game, SIGNAL(message(const QString&)), m_board, SLOT(message(const QString&)));
-	connect(m_board, SIGNAL(numberMoves(int)), m_infoBar, SLOT(updateMoves(int)));
-	connect(m_board, SIGNAL(pendingAnimationsFinished()), this, SLOT(gameIsOver()));
-	m_view->setScene(m_board);
-	m_view->fitInView(0, 0, m_view->width(), m_view->height());
-	//reset the Pause button's state
-	//TODO: move this to the general changeState slot
-	QAction *pauseAction = actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause));
-	pauseAction->setChecked(false);
-	pauseAction->setEnabled(true);
-	QAction *hintAction = actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint));
-	hintAction->setEnabled(true);
-	connect(hintAction, SIGNAL(triggered()), m_board, SLOT(showHint()));
+	m_gameState->startNewGame();
+	m_gameState->setMode(mode);
+	m_game = new Game(m_gameState, KGameDifficulty::level());
+	connect(m_gameState, SIGNAL(stateChanged(KDiamond::State)), m_game, SLOT(stateChange(KDiamond::State)));
+	connect(m_gameState, SIGNAL(message(const QString&)), m_game, SLOT(message(const QString&)));
+	connect(m_game, SIGNAL(numberMoves(int)), m_infoBar, SLOT(updateMoves(int)));
+	connect(m_game, SIGNAL(pendingAnimationsFinished()), this, SLOT(gameIsOver()));
+	connect(m_hintAct, SIGNAL(triggered()), m_game, SLOT(showHint()));
+	m_view->setScene(m_game);
 	//reset status bar
-	//TODO: is this necessary?
 	m_infoBar->setUntimed(mode == KDiamond::UntimedGame);
 	m_infoBar->updatePoints(0);
 	m_infoBar->updateRemainingTime(KDiamond::GameDuration);
@@ -153,24 +138,17 @@ void MainWindow::startGame(KDiamond::Mode mode)
 
 void MainWindow::stateChange(KDiamond::State state)
 {
-	//disable pause button once game is over
-	if (state == KDiamond::Finished)
-	{
-		QAction *pauseAction = actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause));
-		pauseAction->setChecked(false);
-		pauseAction->setEnabled(false);
-	}
-	//hint is only possible while playing
-	QAction *hintAction = actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint));
-	hintAction->setEnabled(state == KDiamond::Playing);
+	m_pauseAct->setEnabled(state != KDiamond::Finished);
+	m_pauseAct->setChecked(state == KDiamond::Paused);
+	m_hintAct->setEnabled(state == KDiamond::Playing);
 }
 
 void MainWindow::gameIsOver()
 {
 	//create score info
 	KScoreDialog::FieldInfo scoreInfo;
-	scoreInfo[KScoreDialog::Score].setNum(m_game->points());
-	scoreInfo[KScoreDialog::Custom1] = m_game->mode() == KDiamond::UntimedGame ? i18n("Untimed") : i18n("Timed");
+	scoreInfo[KScoreDialog::Score].setNum(m_gameState->points());
+	scoreInfo[KScoreDialog::Custom1] = m_gameState->mode() == KDiamond::UntimedGame ? i18n("Untimed") : i18n("Timed");
 	//report score
 	QPointer<KScoreDialog> dialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score, this);
 	dialog->addLocalizedConfigGroupNames(KGameDifficulty::localizedLevelStrings());
@@ -185,8 +163,8 @@ void MainWindow::gameIsOver()
 void MainWindow::showHighscores()
 {
 	//pause game if necessary
-	m_game->setState(KDiamond::Paused);
-	if (m_game->state() != KDiamond::Finished)
+	m_gameState->setState(KDiamond::Paused);
+	if (m_gameState->state() != KDiamond::Finished)
 		actionCollection()->action("game_pause")->setChecked(true);
 	//show dialog
 	QPointer<KScoreDialog> dialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score, this);
@@ -199,13 +177,7 @@ void MainWindow::showHighscores()
 
 void MainWindow::pausedAction(bool paused)
 {
-	m_game->setState(paused ? KDiamond::Paused : KDiamond::Playing);
-}
-
-void MainWindow::updateTheme(bool force)
-{
-	if (m_board)
-		m_board->resizeScene(m_view->width(), m_view->height(), force);
+	m_gameState->setState(paused ? KDiamond::Paused : KDiamond::Playing);
 }
 
 void MainWindow::configureNotifications()
@@ -226,17 +198,7 @@ void MainWindow::configureSettings()
 
 void MainWindow::loadSettings()
 {
-	if (!Renderer::self()->loadTheme(Settings::theme()))
-	{
-		KMessageBox::error(this, i18n("Failed to load \"%1\" theme. Please check your installation.", Settings::theme()));
-		return;
-	}
-	//redraw game scene if necessary
-	if (m_game != 0)
-	{
-		updateTheme(true);
-		m_board->invalidate(m_board->sceneRect(), QGraphicsScene::BackgroundLayer);
-	}
+	KDiamond::renderer()->setTheme(Settings::theme());
 }
 
 #include "mainwindow.moc"
