@@ -20,10 +20,10 @@
 #include "scene.h"
 
 #include "numericdisplayitem.h"
-#include "render.h"
+#include "renderer.h"
 #include "settings.h"
 
-#include "kgamepopupitem.h"
+#include <KGamePopupItem>
 
 #include <KDE/KDebug>
 
@@ -77,7 +77,7 @@ Killbots::Sprite * Killbots::Scene::createSprite( SpriteType type, QPoint positi
 {
 	Sprite * sprite = new Sprite();
 	sprite->setSpriteType( type );
-	sprite->setSize( m_cellSize );
+	sprite->setRenderSize( m_cellSize );
 	sprite->enqueueGridPos( position );
 	updateSpritePos( sprite, position );
 	sprite->scale( 0, 0 );
@@ -178,7 +178,7 @@ void Killbots::Scene::doLayout()
 	const int baseDimension = qMin( size.width(), size.height() ) / 35;
 	const int spacing = qBound( 5, baseDimension, 15 );
 	const int newFontPixelSize = qBound( QFontInfo( QFont() ).pixelSize(), baseDimension, 25 );
-	const qreal aspectRatio = Render::aspectRatio();
+	const qreal aspectRatio = Renderer::self()->aspectRatio();
 
 	QSize displaySize;
 	// If the font size has changed, resize all the displays (visible or not).
@@ -193,7 +193,7 @@ void Killbots::Scene::doLayout()
 			displaySize = displaySize.expandedTo( display->preferredSize() );
 		}
 		foreach ( NumericDisplayItem * display, m_numericDisplays )
-			display->setSize( displaySize );
+			display->setRenderSize( displaySize );
 	}
 	else
 	{
@@ -238,7 +238,7 @@ void Killbots::Scene::doLayout()
 		Sprite * sprite = qgraphicsitem_cast<Sprite *>( item );
 		if ( sprite )
 		{
-			sprite->setSize( m_cellSize );
+			sprite->setRenderSize( m_cellSize );
 			updateSpritePos( sprite, sprite->currentGridPos() );
 		}
 	}
@@ -301,24 +301,31 @@ void Killbots::Scene::doLayout()
 		setSceneRect( QRectF( sceneRectXPos, sceneRectYPos, size.width(), size.height() ) );
 	}
 
-	update();
-}
-
-
-void Killbots::Scene::drawBackground( QPainter * painter, const QRectF & rect )
-{
-	Q_UNUSED( rect )
-
-	QSize sceneSize( qRound( sceneRect().width() ), qRound( sceneRect().height() ) );
-	painter->drawPixmap( sceneRect().topLeft(), Render::renderElement( "background", sceneSize ) );
-
-	QRect gridArea( -m_cellSize.width() / 2,
-	                -m_cellSize.height() / 2,
+	// Update the scene background
+	QPainter p;
+	QRect gridRect( -sceneRect().x() - m_cellSize.width() / 2,
+	                -sceneRect().y() - m_cellSize.height() / 2,
 	                m_columns * m_cellSize.width(),
 	                m_rows * m_cellSize.height()
 	              );
-	painter->setCompositionMode( QPainter::CompositionMode_SourceOver );
-	painter->drawTiledPixmap( gridArea, Render::renderElement( "cell", m_cellSize ) );
+
+	QPixmap unrotated = Renderer::self()->spritePixmap( "background", size );
+	p.begin( &unrotated );
+	p.drawTiledPixmap( gridRect, Renderer::self()->spritePixmap( "cell", m_cellSize ) );
+	p.end();
+
+	// The background brush begins painting at 0,0 but our sceneRect doesn't
+	// start at 0,0 so we have to "rotate" the pixmap so that it looks right
+	// when tiled.
+	QPixmap background( size );
+	background.fill( Qt::transparent );
+	p.begin( &background );
+	p.drawTiledPixmap( background.rect(), unrotated, -sceneRect().topLeft().toPoint() );
+	p.end();
+
+	setBackgroundBrush( background );
+
+	update();
 }
 
 
@@ -388,7 +395,7 @@ Killbots::HeroAction Killbots::Scene::getMouseDirection( QPointF cursorPosition
 			result = static_cast<HeroAction>( direction );
 		}
 
-		views().first()->setCursor( Render::cursorFromAction( result ) );
+		views().first()->setCursor( Renderer::self()->cursorFromAction( result ) );
 	}
 	else
 	{
