@@ -19,8 +19,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef _GAMELOGIC_H_
-#define _GAMELOGIC_H_
+#ifndef KONQUEST_GAMELOGIC_H
+#define KONQUEST_GAMELOGIC_H
 
 struct GameOptions
 {
@@ -109,4 +109,4 @@ private:
 };
 
 
-#endif  // _GAMELOGIC_H_
+#endif  // KONQUEST_GAMELOGIC_H
